#!/bin/ksh

ROOTCATALOG=${ROOTCATALOG:-/etc/xml/catalog}
CATALOG=${CATALOG:-/etc/xml/docbook-xsl-1.69.1.cat}
CLIENT_BASEDIR=${CLIENT_BASEDIR:-@CLIENT_BASEDIR@}
XMLCATALOG=${XMLCATALOG:-`which xmlcatalog 2>/dev/null`}

if [ "$1" = "-r" ]; then
	REMOVE="true"
else
	REMOVE=""
fi

ROOT="${PKG_INSTALL_ROOT}"
if [ ! -d ${ROOT}/etc/xml ]; then
    mkdir -p ${ROOT}/etc/xml
    chmod 0755 ${ROOT}/etc/xml
    chown bin:bin ${ROOT}/etc/xml
fi
echo "Using $ROOT$ROOTCATALOG for root catalog."
if [ ! -r ${ROOT}$ROOTCATALOG ]; then
	$XMLCATALOG --noout --create "${ROOT}$ROOTCATALOG"
fi
if [ ! -r ${ROOT}$CATALOG ]; then
	 $XMLCATALOG --noout --create "${ROOT}$CATALOG"
fi

# where we start to increment minor version
MINOR_START=48

# determine the end
set -A VERS `echo "1.69.1" | tr '.' ' '`
MAJOR=${VERS[0]}
MINOR=${VERS[1]}
MINI=${VERS[2]}

DIR=${CLIENT_BASEDIR}/docbook/xsl/1.69.1

COUNT=$MINOR_START
while [ $COUNT -le $MINOR ]; do
	DPID="http://docbook.sourceforge.net/release/xsl/${MAJOR}.${COUNT}"
	if [ -z "$REMOVE" ]; then
		$XMLCATALOG --noout --add rewriteSystem "$DPID" "file://$DIR" "${ROOT}$CATALOG"
	else
		$XMLCATALOG --noout --del "file://${DIR}" "${ROOT}$CATALOG"
	fi
	COUNT=$((COUNT+1))
done
DPID="http://docbook.sourceforge.net/release/xsl/current"
if [ -z "$REMOVE" ]; then
	$XMLCATALOG --noout --add rewriteSystem "$DPID" "file://$DIR" "${ROOT}$CATALOG"
else
	$XMLCATALOG --noout --del "file://${DIR}" "${ROOT}$CATALOG"
fi

# super catalog
set -A ENTITIES3 \
	'delegatePublic' 'http://docbook.sourceforge.net/release/xsl/' \
	'delegateSystem' 'http://docbook.sourceforge.net/release/xsl/' \
	'delegateURI' 'http://docbook.sourceforge.net/release/xsl/' \

LEN=${#ENTITIES3[@]}
COUNT=0
while [ $COUNT -lt $LEN ]; do
	ACTION=${ENTITIES3[$COUNT]}
	COUNT=$((COUNT+1))
	DID=${ENTITIES3[$COUNT]}
	COUNT=$((COUNT+1))
	if [ -z "$REMOVE" ]; then
		$XMLCATALOG --noout --add "$ACTION" "$DID" "file://$CATALOG" "${ROOT}$ROOTCATALOG"
	else
		$XMLCATALOG --noout --del "file://$CATALOG" "${ROOT}$ROOTCATALOG"
	fi
done
